==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-faq-light/dictionaries/de.dict.itop-faq-light.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author ITOMIG GmbH <martin.raenker@itomig.de>
 *
 */
Dict::Add('DE DE', 'German', 'Deutsch', [
	'Brick:Portal:FAQ:Menu' => 'FAQ',
	'Brick:Portal:FAQ:Title' => 'Oft gestellte Fragen (FAQs)',
	'Brick:Portal:FAQ:Title+' => '<p>In Eile?</p><p>Sehen Sie sich die meistgestellten Fragen an (FAQs) und finden Sie (eventuell) die Antwort direkt dort.</p>',
	'Class:FAQ' => 'FAQ',
	'Class:FAQ+' => '',
	'Class:FAQ/Attribute:category_id' => 'Kategorie',
	'Class:FAQ/Attribute:category_id+' => '',
	'Class:FAQ/Attribute:category_name' => 'Kategoriename',
	'Class:FAQ/Attribute:category_name+' => '',
	'Class:FAQ/Attribute:description' => 'Beschreibung',
	'Class:FAQ/Attribute:description+' => '',
	'Class:FAQ/Attribute:domains' => 'Domäne',
	'Class:FAQ/Attribute:error_code' => 'Fehlercode',
	'Class:FAQ/Attribute:error_code+' => '',
	'Class:FAQ/Attribute:key_words' => 'Schlüsselwörter',
	'Class:FAQ/Attribute:key_words+' => '',
	'Class:FAQ/Attribute:summary' => 'Zusammenfassung',
	'Class:FAQ/Attribute:summary+' => '',
	'Class:FAQ/Attribute:title' => 'Titel',
	'Class:FAQ/Attribute:title+' => '',
	'Class:FAQCategory' => 'FAQ-Kategorie',
	'Class:FAQCategory+' => '',
	'Class:FAQCategory/Attribute:faq_list' => 'FAQs',
	'Class:FAQCategory/Attribute:faq_list+' => 'Alle FAQ-Einträge (frequently asked questions) verknüpft mit dieser Kategorie',
	'Class:FAQCategory/Attribute:name' => 'Name',
	'Class:FAQCategory/Attribute:name+' => '',
	'Menu:FAQ' => 'FAQs',
	'Menu:FAQ+' => '',
	'Menu:FAQCategory' => 'FAQ-Kategorien',
	'Menu:FAQCategory+' => '',
	'Menu:Problem:Shortcuts' => 'Shortcuts',
	'Menu:ProblemManagement' => 'Problem Management',
	'Menu:ProblemManagement+' => 'Problem Management',
]);

==> iTop-3.2.1-1-16749.zip: web/datamodels/2.x/itop-faq-light/dictionaries/de.dict.itop-faq-light.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author ITOMIG GmbH <martin.raenker@itomig.de>
 *
 */
Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Class:FAQ' => 'FAQ',
	'Class:FAQ+' => '',
	'Class:FAQ/Attribute:title' => 'Titel',
	'Class:FAQ/Attribute:title+' => '',
	'Class:FAQ/Attribute:summary' => 'Zusammenfassung',
	'Class:FAQ/Attribute:summary+' => '',
	'Class:FAQ/Attribute:description' => 'Beschreibung',
	'Class:FAQ/Attribute:description+' => '',
	'Class:FAQ/Attribute:category_id' => 'Kategorie',
	'Class:FAQ/Attribute:category_id+' => '',
	'Class:FAQ/Attribute:category_name' => 'Kategoriename',
	'Class:FAQ/Attribute:category_name+' => '',
	'Class:FAQ/Attribute:error_code' => 'Fehlercode',
	'Class:FAQ/Attribute:error_code+' => '',
	'Class:FAQ/Attribute:key_words' => 'Schlüsselwörter',
	'Class:FAQ/Attribute:key_words+' => '',
	'Class:FAQ/Attribute:domains' => 'Domäne',
));

//
// Class: FAQCategory
//

Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Class:FAQCategory' => 'FAQ-Kategorie',
	'Class:FAQCategory+' => '',
	'Class:FAQCategory/Attribute:name' => 'Name',
	'Class:FAQCategory/Attribute:name+' => '',
	'Class:FAQCategory/Attribute:faq_list' => 'FAQs',
	'Class:FAQCategory/Attribute:faq_list+' => 'Alle FAQ-Einträge (frequently asked questions) verknüpft mit dieser Kategorie',
));
Dict::Add('DE DE', 'German', 'Deutsch', array(
	'Menu:ProblemManagement' => 'Problem Management',
	'Menu:ProblemManagement+' => 'Problem Management',
	'Menu:Problem:Shortcuts' => 'Shortcuts',
	'Menu:FAQCategory' => 'FAQ-Kategorien',
	'Menu:FAQCategory+' => '',
	'Menu:FAQ' => 'FAQs',
	'Menu:FAQ+' => '',
	'Brick:Portal:FAQ:Menu' => 'FAQ',
	'Brick:Portal:FAQ:Title' => 'Oft gestellte Fragen (FAQs)',
	'Brick:Portal:FAQ:Title+' => '<p>In Eile?</p><p>Sehen Sie sich die meistgestellten Fragen an (FAQs) und finden Sie (eventuell) die Antwort direkt dort.</p>',
));
